"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_planning_pb2 as ares__planning__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .planning import manual_planner_pb2 as planning_dot_manual__planner__pb2
from .planning import planner_status_pb2 as planning_dot_planner__status__pb2
GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in ares_planning_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresPlanningStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAllPlanners = channel.unary_unary('/ares.messaging.planning.AresPlanning/GetAllPlanners', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__planning__pb2.GetAllPlannersResponse.FromString, _registered_method=True)
        self.GetPlannerCapabilities = channel.unary_unary('/ares.messaging.planning.AresPlanning/GetPlannerCapabilities', request_serializer=ares__planning__pb2.CapabilitiesRequest.SerializeToString, response_deserializer=ares__planning__pb2.CapabilitiesResponse.FromString, _registered_method=True)
        self.GetPlannerSettings = channel.unary_unary('/ares.messaging.planning.AresPlanning/GetPlannerSettings', request_serializer=ares__planning__pb2.PlannerSettingsRequest.SerializeToString, response_deserializer=ares__planning__pb2.PlannerSettingsResponse.FromString, _registered_method=True)
        self.GetPlannerStatus = channel.unary_unary('/ares.messaging.planning.AresPlanning/GetPlannerStatus', request_serializer=ares__planning__pb2.PlannerStatusRequest.SerializeToString, response_deserializer=planning_dot_planner__status__pb2.PlannerStatus.FromString, _registered_method=True)
        self.ActivatePlanner = channel.unary_unary('/ares.messaging.planning.AresPlanning/ActivatePlanner', request_serializer=ares__planning__pb2.PlannerActivationRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.SeedManualPlanner = channel.unary_unary('/ares.messaging.planning.AresPlanning/SeedManualPlanner', request_serializer=planning_dot_manual__planner__pb2.ManualPlannerSeed.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.GetManualPlannerSeed = channel.unary_unary('/ares.messaging.planning.AresPlanning/GetManualPlannerSeed', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=planning_dot_manual__planner__pb2.ManualPlannerSetCollection.FromString, _registered_method=True)
        self.ResetManualPlanner = channel.unary_unary('/ares.messaging.planning.AresPlanning/ResetManualPlanner', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.AddPlanner = channel.unary_unary('/ares.messaging.planning.AresPlanning/AddPlanner', request_serializer=ares__planning__pb2.GenericPlanner.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.RemovePlanner = channel.unary_unary('/ares.messaging.planning.AresPlanning/RemovePlanner', request_serializer=ares__planning__pb2.GenericPlanner.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)
        self.UpdatePlanner = channel.unary_unary('/ares.messaging.planning.AresPlanning/UpdatePlanner', request_serializer=ares__planning__pb2.GenericPlanner.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)

class AresPlanningServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAllPlanners(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlannerCapabilities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlannerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlannerStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivatePlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SeedManualPlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetManualPlannerSeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetManualPlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePlanner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresPlanningServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetAllPlanners': grpc.unary_unary_rpc_method_handler(servicer.GetAllPlanners, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__planning__pb2.GetAllPlannersResponse.SerializeToString), 'GetPlannerCapabilities': grpc.unary_unary_rpc_method_handler(servicer.GetPlannerCapabilities, request_deserializer=ares__planning__pb2.CapabilitiesRequest.FromString, response_serializer=ares__planning__pb2.CapabilitiesResponse.SerializeToString), 'GetPlannerSettings': grpc.unary_unary_rpc_method_handler(servicer.GetPlannerSettings, request_deserializer=ares__planning__pb2.PlannerSettingsRequest.FromString, response_serializer=ares__planning__pb2.PlannerSettingsResponse.SerializeToString), 'GetPlannerStatus': grpc.unary_unary_rpc_method_handler(servicer.GetPlannerStatus, request_deserializer=ares__planning__pb2.PlannerStatusRequest.FromString, response_serializer=planning_dot_planner__status__pb2.PlannerStatus.SerializeToString), 'ActivatePlanner': grpc.unary_unary_rpc_method_handler(servicer.ActivatePlanner, request_deserializer=ares__planning__pb2.PlannerActivationRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'SeedManualPlanner': grpc.unary_unary_rpc_method_handler(servicer.SeedManualPlanner, request_deserializer=planning_dot_manual__planner__pb2.ManualPlannerSeed.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'GetManualPlannerSeed': grpc.unary_unary_rpc_method_handler(servicer.GetManualPlannerSeed, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=planning_dot_manual__planner__pb2.ManualPlannerSetCollection.SerializeToString), 'ResetManualPlanner': grpc.unary_unary_rpc_method_handler(servicer.ResetManualPlanner, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'AddPlanner': grpc.unary_unary_rpc_method_handler(servicer.AddPlanner, request_deserializer=ares__planning__pb2.GenericPlanner.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'RemovePlanner': grpc.unary_unary_rpc_method_handler(servicer.RemovePlanner, request_deserializer=ares__planning__pb2.GenericPlanner.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString), 'UpdatePlanner': grpc.unary_unary_rpc_method_handler(servicer.UpdatePlanner, request_deserializer=ares__planning__pb2.GenericPlanner.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.messaging.planning.AresPlanning', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.messaging.planning.AresPlanning', rpc_method_handlers)

class AresPlanning(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAllPlanners(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/GetAllPlanners', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__planning__pb2.GetAllPlannersResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetPlannerCapabilities(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/GetPlannerCapabilities', ares__planning__pb2.CapabilitiesRequest.SerializeToString, ares__planning__pb2.CapabilitiesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetPlannerSettings(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/GetPlannerSettings', ares__planning__pb2.PlannerSettingsRequest.SerializeToString, ares__planning__pb2.PlannerSettingsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetPlannerStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/GetPlannerStatus', ares__planning__pb2.PlannerStatusRequest.SerializeToString, planning_dot_planner__status__pb2.PlannerStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ActivatePlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/ActivatePlanner', ares__planning__pb2.PlannerActivationRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def SeedManualPlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/SeedManualPlanner', planning_dot_manual__planner__pb2.ManualPlannerSeed.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetManualPlannerSeed(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/GetManualPlannerSeed', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, planning_dot_manual__planner__pb2.ManualPlannerSetCollection.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ResetManualPlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/ResetManualPlanner', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def AddPlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/AddPlanner', ares__planning__pb2.GenericPlanner.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemovePlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/RemovePlanner', ares__planning__pb2.GenericPlanner.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdatePlanner(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.messaging.planning.AresPlanning/UpdatePlanner', ares__planning__pb2.GenericPlanner.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'planning/ares_planner.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bplanning/ares_planner.proto\x12\x17ares.datamodel.planning\x1a\x1bgoogle/protobuf/empty.proto"\xbe\x01\n\x0cCapabilities\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x02 \x01(\x03\x12<\n\x12available_planners\x18\x03 \x03(\x0b2 .ares.datamodel.planning.Planner\x12A\n\x10adapter_settings\x18\x04 \x03(\x0b2\'.ares.datamodel.planning.PlannerSetting"X\n\x07Planner\x12\x14\n\x0cplanner_name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x11\n\tunique_id\x18\x04 \x01(\t"v\n\x0ePlannerSetting\x12\x14\n\x0csetting_name\x18\x01 \x01(\t\x12<\n\rsetting_value\x18\x02 \x01(\x0b2%.ares.datamodel.planning.SettingValue\x12\x10\n\x08optional\x18\x03 \x01(\x08"\xbe\x01\n\x0cSettingValue\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint32_value\x18\x02 \x01(\x05H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x15\n\x0bfloat_value\x18\x04 \x01(\x02H\x00\x12\x16\n\x0cdouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0bbytes_value\x18\x07 \x01(\x0cH\x00B\x0c\n\nvalue_data"V\n\x0bPlanRequest\x12G\n\x13planning_parameters\x18\x01 \x03(\x0b2*.ares.datamodel.planning.PlanningParameter"A\n\x0cPlanResponse\x12\x17\n\x0fparameter_names\x18\x01 \x03(\t\x12\x18\n\x10parameter_values\x18\x02 \x03(\x02"\xad\x02\n\x11PlanningParameter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x12\x17\n\x0fparameter_value\x18\x02 \x01(\x01\x12\x15\n\rminimum_value\x18\x03 \x01(\x01\x12\x15\n\rmaximum_value\x18\x04 \x01(\x01\x12\x19\n\x11minimum_precision\x18\x05 \x01(\x01\x12\x19\n\x11parameter_history\x18\x06 \x03(\x01\x12\x11\n\tdata_type\x18\x07 \x01(\t\x123\n\x08metadata\x18\x08 \x01(\x0b2!.ares.datamodel.planning.Metadata\x12\x12\n\nis_planned\x18\t \x01(\x08\x12\x11\n\tis_result\x18\n \x01(\x08\x12\x14\n\x0cplanner_name\x18\x0b \x01(\t"x\n\x10PlannedParameter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x12\x17\n\x0fparameter_value\x18\x02 \x01(\x01\x123\n\x08metadata\x18\x03 \x01(\x0b2!.ares.datamodel.planning.Metadata"!\n\x08Metadata\x12\x15\n\rmetadata_name\x18\x01 \x01(\t2\xbc\x01\n\x0fAresPlannerGrpc\x12T\n\x13RequestCapabilities\x12\x16.google.protobuf.Empty\x1a%.ares.datamodel.planning.Capabilities\x12S\n\x04Plan\x12$.ares.datamodel.planning.PlanRequest\x1a%.ares.datamodel.planning.PlanResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'planning.ares_planner_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CAPABILITIES']._serialized_start = 86
    _globals['_CAPABILITIES']._serialized_end = 276
    _globals['_PLANNER']._serialized_start = 278
    _globals['_PLANNER']._serialized_end = 366
    _globals['_PLANNERSETTING']._serialized_start = 368
    _globals['_PLANNERSETTING']._serialized_end = 486
    _globals['_SETTINGVALUE']._serialized_start = 489
    _globals['_SETTINGVALUE']._serialized_end = 679
    _globals['_PLANREQUEST']._serialized_start = 681
    _globals['_PLANREQUEST']._serialized_end = 767
    _globals['_PLANRESPONSE']._serialized_start = 769
    _globals['_PLANRESPONSE']._serialized_end = 834
    _globals['_PLANNINGPARAMETER']._serialized_start = 837
    _globals['_PLANNINGPARAMETER']._serialized_end = 1138
    _globals['_PLANNEDPARAMETER']._serialized_start = 1140
    _globals['_PLANNEDPARAMETER']._serialized_end = 1260
    _globals['_METADATA']._serialized_start = 1262
    _globals['_METADATA']._serialized_end = 1295
    _globals['_ARESPLANNERGRPC']._serialized_start = 1298
    _globals['_ARESPLANNERGRPC']._serialized_end = 1486


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'plan_transaction.proto')
_sym_db = _symbol_database.Default()
from . import planner_adapter_info_pb2 as planner__adapter__info__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from .planning import ares_planner_pb2 as planning_dot_ares__planner__pb2
from .templates import parameter_metadata_pb2 as templates_dot_parameter__metadata__pb2
from . import ares_struct_pb2 as ares__struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16plan_transaction.proto\x12\x0eares.datamodel\x1a\x1aplanner_adapter_info.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bplanning/ares_planner.proto\x1a"templates/parameter_metadata.proto\x1a\x11ares_struct.proto"\xa2\x02\n\x12PlannerTransaction\x12/\n\tunique_id\x18\x01 \x01(\x0b2\x1c.google.protobuf.StringValue\x125\n\x07request\x18\x02 \x01(\x0b2$.ares.datamodel.planning.PlanRequest\x12,\n\x08response\x18\x03 \x03(\x0b2\x1a.ares.datamodel.PlanResult\x128\n\x0cplanner_info\x18\x04 \x01(\x0b2".ares.datamodel.PlannerAdapterInfo\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12+\n\x05error\x18\x06 \x01(\x0b2\x1c.google.protobuf.StringValue"\xb0\x01\n\nPlanResult\x12/\n\tunique_id\x18\x01 \x01(\x0b2\x1c.google.protobuf.StringValue\x12(\n\x05value\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue\x12G\n\x12parameter_metadata\x18\x03 \x01(\x0b2+.ares.datamodel.templates.ParameterMetadatab\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'plan_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PLANNERTRANSACTION']._serialized_start = 187
    _globals['_PLANNERTRANSACTION']._serialized_end = 477
    _globals['_PLANRESULT']._serialized_start = 480
    _globals['_PLANRESULT']._serialized_end = 656


"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from . import ares_devices_pb2 as ares__devices__pb2
from .device import device_status_pb2 as device_dot_device__status__pb2
from . import device_command_result_pb2 as device__command__result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .templates import command_template_pb2 as templates_dot_command__template__pb2
GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in ares_devices_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class AresDevicesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAresDevices = channel.unary_unary('/ares.services.device.AresDevices/ListAresDevices', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.ListAresDevicesResponse.FromString, _registered_method=True)
        self.GetServerSerialPorts = channel.unary_unary('/ares.services.device.AresDevices/GetServerSerialPorts', request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, response_deserializer=ares__devices__pb2.ListServerSerialPortsResponse.FromString, _registered_method=True)
        self.GetDeviceStatus = channel.unary_unary('/ares.services.device.AresDevices/GetDeviceStatus', request_serializer=ares__devices__pb2.DeviceStatusRequest.SerializeToString, response_deserializer=device_dot_device__status__pb2.DeviceStatus.FromString, _registered_method=True)
        self.GetCommandMetadatas = channel.unary_unary('/ares.services.device.AresDevices/GetCommandMetadatas', request_serializer=ares__devices__pb2.CommandMetadatasRequest.SerializeToString, response_deserializer=ares__devices__pb2.CommandMetadatasResponse.FromString, _registered_method=True)
        self.ExecuteCommand = channel.unary_unary('/ares.services.device.AresDevices/ExecuteCommand', request_serializer=templates_dot_command__template__pb2.CommandTemplate.SerializeToString, response_deserializer=device__command__result__pb2.DeviceCommandResult.FromString, _registered_method=True)
        self.GetAllDeviceConfigs = channel.unary_unary('/ares.services.device.AresDevices/GetAllDeviceConfigs', request_serializer=ares__devices__pb2.DeviceConfigRequest.SerializeToString, response_deserializer=ares__devices__pb2.DeviceConfigResponse.FromString, _registered_method=True)
        self.Activate = channel.unary_unary('/ares.services.device.AresDevices/Activate', request_serializer=ares__devices__pb2.DeviceActivateRequest.SerializeToString, response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, _registered_method=True)

class AresDevicesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAresDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServerSerialPorts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommandMetadatas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllDeviceConfigs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_AresDevicesServicer_to_server(servicer, server):
    rpc_method_handlers = {'ListAresDevices': grpc.unary_unary_rpc_method_handler(servicer.ListAresDevices, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.ListAresDevicesResponse.SerializeToString), 'GetServerSerialPorts': grpc.unary_unary_rpc_method_handler(servicer.GetServerSerialPorts, request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString, response_serializer=ares__devices__pb2.ListServerSerialPortsResponse.SerializeToString), 'GetDeviceStatus': grpc.unary_unary_rpc_method_handler(servicer.GetDeviceStatus, request_deserializer=ares__devices__pb2.DeviceStatusRequest.FromString, response_serializer=device_dot_device__status__pb2.DeviceStatus.SerializeToString), 'GetCommandMetadatas': grpc.unary_unary_rpc_method_handler(servicer.GetCommandMetadatas, request_deserializer=ares__devices__pb2.CommandMetadatasRequest.FromString, response_serializer=ares__devices__pb2.CommandMetadatasResponse.SerializeToString), 'ExecuteCommand': grpc.unary_unary_rpc_method_handler(servicer.ExecuteCommand, request_deserializer=templates_dot_command__template__pb2.CommandTemplate.FromString, response_serializer=device__command__result__pb2.DeviceCommandResult.SerializeToString), 'GetAllDeviceConfigs': grpc.unary_unary_rpc_method_handler(servicer.GetAllDeviceConfigs, request_deserializer=ares__devices__pb2.DeviceConfigRequest.FromString, response_serializer=ares__devices__pb2.DeviceConfigResponse.SerializeToString), 'Activate': grpc.unary_unary_rpc_method_handler(servicer.Activate, request_deserializer=ares__devices__pb2.DeviceActivateRequest.FromString, response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ares.services.device.AresDevices', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ares.services.device.AresDevices', rpc_method_handlers)

class AresDevices(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAresDevices(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/ListAresDevices', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.ListAresDevicesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetServerSerialPorts(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetServerSerialPorts', google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString, ares__devices__pb2.ListServerSerialPortsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetDeviceStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetDeviceStatus', ares__devices__pb2.DeviceStatusRequest.SerializeToString, device_dot_device__status__pb2.DeviceStatus.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetCommandMetadatas(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetCommandMetadatas', ares__devices__pb2.CommandMetadatasRequest.SerializeToString, ares__devices__pb2.CommandMetadatasResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ExecuteCommand(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/ExecuteCommand', templates_dot_command__template__pb2.CommandTemplate.SerializeToString, device__command__result__pb2.DeviceCommandResult.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetAllDeviceConfigs(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/GetAllDeviceConfigs', ares__devices__pb2.DeviceConfigRequest.SerializeToString, ares__devices__pb2.DeviceConfigResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def Activate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ares.services.device.AresDevices/Activate', ares__devices__pb2.DeviceActivateRequest.SerializeToString, google_dot_protobuf_dot_empty__pb2.Empty.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_devices.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .templates import command_metadata_pb2 as templates_dot_command__metadata__pb2
from .templates import command_template_pb2 as templates_dot_command__template__pb2
from . import device_command_result_pb2 as device__command__result__pb2
from .device import device_status_pb2 as device_dot_device__status__pb2
from .device import device_config_pb2 as device_dot_device__config__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ares_devices.proto\x12\x14ares.services.device\x1a\x1bgoogle/protobuf/empty.proto\x1a templates/command_metadata.proto\x1a templates/command_template.proto\x1a\x1bdevice_command_result.proto\x1a\x1adevice/device_status.proto\x1a\x1adevice/device_config.proto",\n\x0eAresDeviceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t"U\n\x17ListAresDevicesResponse\x12:\n\x0cares_devices\x18\x01 \x03(\x0b2$.ares.services.device.AresDeviceInfo"5\n\x1dListServerSerialPortsResponse\x12\x14\n\x0cserial_ports\x18\x01 \x03(\t".\n\x17CommandMetadatasRequest\x12\x13\n\x0bdevice_name\x18\x01 \x01(\t"X\n\x18CommandMetadatasResponse\x12<\n\tmetadatas\x18\x01 \x03(\x0b2).ares.datamodel.templates.CommandMetadata"*\n\x13DeviceStatusRequest\x12\x13\n\x0bdevice_name\x18\x01 \x01(\t",\n\x15DeviceActivateRequest\x12\x13\n\x0bdevice_name\x18\x01 \x01(\t"*\n\x13DeviceConfigRequest\x12\x13\n\x0bdevice_type\x18\x01 \x01(\t"L\n\x14DeviceConfigResponse\x124\n\x07configs\x18\x01 \x03(\x0b2#.ares.datamodel.device.DeviceConfig2\xc6\x05\n\x0bAresDevices\x12X\n\x0fListAresDevices\x12\x16.google.protobuf.Empty\x1a-.ares.services.device.ListAresDevicesResponse\x12c\n\x14GetServerSerialPorts\x12\x16.google.protobuf.Empty\x1a3.ares.services.device.ListServerSerialPortsResponse\x12a\n\x0fGetDeviceStatus\x12).ares.services.device.DeviceStatusRequest\x1a#.ares.datamodel.device.DeviceStatus\x12t\n\x13GetCommandMetadatas\x12-.ares.services.device.CommandMetadatasRequest\x1a..ares.services.device.CommandMetadatasResponse\x12`\n\x0eExecuteCommand\x12).ares.datamodel.templates.CommandTemplate\x1a#.ares.datamodel.DeviceCommandResult\x12l\n\x13GetAllDeviceConfigs\x12).ares.services.device.DeviceConfigRequest\x1a*.ares.services.device.DeviceConfigResponse\x12O\n\x08Activate\x12+.ares.services.device.DeviceActivateRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_devices_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESDEVICEINFO']._serialized_start = 226
    _globals['_ARESDEVICEINFO']._serialized_end = 270
    _globals['_LISTARESDEVICESRESPONSE']._serialized_start = 272
    _globals['_LISTARESDEVICESRESPONSE']._serialized_end = 357
    _globals['_LISTSERVERSERIALPORTSRESPONSE']._serialized_start = 359
    _globals['_LISTSERVERSERIALPORTSRESPONSE']._serialized_end = 412
    _globals['_COMMANDMETADATASREQUEST']._serialized_start = 414
    _globals['_COMMANDMETADATASREQUEST']._serialized_end = 460
    _globals['_COMMANDMETADATASRESPONSE']._serialized_start = 462
    _globals['_COMMANDMETADATASRESPONSE']._serialized_end = 550
    _globals['_DEVICESTATUSREQUEST']._serialized_start = 552
    _globals['_DEVICESTATUSREQUEST']._serialized_end = 594
    _globals['_DEVICEACTIVATEREQUEST']._serialized_start = 596
    _globals['_DEVICEACTIVATEREQUEST']._serialized_end = 640
    _globals['_DEVICECONFIGREQUEST']._serialized_start = 642
    _globals['_DEVICECONFIGREQUEST']._serialized_end = 684
    _globals['_DEVICECONFIGRESPONSE']._serialized_start = 686
    _globals['_DEVICECONFIGRESPONSE']._serialized_end = 762
    _globals['_ARESDEVICES']._serialized_start = 765
    _globals['_ARESDEVICES']._serialized_end = 1475


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_analyzer_management_service.proto')
_sym_db = _symbol_database.Default()
from .analyzing import analyzer_info_pb2 as analyzing_dot_analyzer__info__pb2
from .analyzing import analyzer_state_pb2 as analyzing_dot_analyzer__state__pb2
from .analyzing import analyzer_settings_pb2 as analyzing_dot_analyzer__settings__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ares_analyzer_management_service.proto\x12\rares.services\x1a\x1danalyzing/analyzer_info.proto\x1a\x1eanalyzing/analyzer_state.proto\x1a!analyzing/analyzer_settings.proto\x1a\x11ares_struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto"T\n\x17GetAllAnalyzersResponse\x129\n\tanalyzers\x18\x01 \x03(\x0b2&.ares.datamodel.analyzing.AnalyzerInfo"5\n\x18AddRemoteAnalyzerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t"\x94\x01\n\x19AddRemoteAnalyzerResponse\x121\n\x0banalyzer_id\x18\x01 \x01(\x0b2\x1c.google.protobuf.StringValue\x12\x0f\n\x07success\x18\x02 \x01(\x08\x123\n\rerror_message\x18\x03 \x01(\x0b2\x1c.google.protobuf.StringValue"\x89\x01\n\x1bUpdateRemoteAnalyzerRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t\x12*\n\x04name\x18\x02 \x01(\x0b2\x1c.google.protobuf.StringValue\x12)\n\x03url\x18\x03 \x01(\x0b2\x1c.google.protobuf.StringValue"d\n\x1cUpdateRemoteAnalyzerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x123\n\rerror_message\x18\x02 \x01(\x0b2\x1c.google.protobuf.StringValue"\x96\x01\n\x1bRemoveRemoteAnalyzerRequest\x121\n\x0banalyzer_id\x18\x01 \x01(\x0b2\x1c.google.protobuf.StringValue\x12\x0f\n\x07success\x18\x02 \x01(\x08\x123\n\rerror_message\x18\x03 \x01(\x0b2\x1c.google.protobuf.StringValue"+\n\x14AnalyzerStateRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t"f\n\x15AnalyzerStateResponse\x126\n\x05state\x18\x01 \x01(\x0e2\'.ares.datamodel.analyzing.AnalyzerState\x12\x15\n\rstate_message\x18\x02 \x01(\t"*\n\x13AnalyzerInfoRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t"L\n\x14AnalyzerInfoResponse\x124\n\x04info\x18\x01 \x01(\x0b2&.ares.datamodel.analyzing.AnalyzerInfo".\n\x17AnalyzerSettingsRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t2\x88\x06\n\x1dAresAnalyzerManagementService\x12Q\n\x0fGetAllAnalyzers\x12\x16.google.protobuf.Empty\x1a&.ares.services.GetAllAnalyzersResponse\x12f\n\x11AddRemoteAnalyzer\x12\'.ares.services.AddRemoteAnalyzerRequest\x1a(.ares.services.AddRemoteAnalyzerResponse\x12o\n\x14UpdateRemoteAnalyzer\x12*.ares.services.UpdateRemoteAnalyzerRequest\x1a+.ares.services.UpdateRemoteAnalyzerResponse\x12Z\n\x14RemoveRemoteAnalyzer\x12*.ares.services.RemoveRemoteAnalyzerRequest\x1a\x16.google.protobuf.Empty\x12U\n\x08GetState\x12#.ares.services.AnalyzerStateRequest\x1a$.ares.services.AnalyzerStateResponse\x12R\n\x07GetInfo\x12".ares.services.AnalyzerInfoRequest\x1a#.ares.services.AnalyzerInfoResponse\x12Y\n\x13SetAnalyzerSettings\x12*.ares.datamodel.analyzing.AnalyzerSettings\x1a\x16.google.protobuf.Empty\x12Y\n\x13GetAnalyzerSettings\x12&.ares.services.AnalyzerSettingsRequest\x1a\x1a.ares.datamodel.AresStructb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_analyzer_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETALLANALYZERSRESPONSE']._serialized_start = 235
    _globals['_GETALLANALYZERSRESPONSE']._serialized_end = 319
    _globals['_ADDREMOTEANALYZERREQUEST']._serialized_start = 321
    _globals['_ADDREMOTEANALYZERREQUEST']._serialized_end = 374
    _globals['_ADDREMOTEANALYZERRESPONSE']._serialized_start = 377
    _globals['_ADDREMOTEANALYZERRESPONSE']._serialized_end = 525
    _globals['_UPDATEREMOTEANALYZERREQUEST']._serialized_start = 528
    _globals['_UPDATEREMOTEANALYZERREQUEST']._serialized_end = 665
    _globals['_UPDATEREMOTEANALYZERRESPONSE']._serialized_start = 667
    _globals['_UPDATEREMOTEANALYZERRESPONSE']._serialized_end = 767
    _globals['_REMOVEREMOTEANALYZERREQUEST']._serialized_start = 770
    _globals['_REMOVEREMOTEANALYZERREQUEST']._serialized_end = 920
    _globals['_ANALYZERSTATEREQUEST']._serialized_start = 922
    _globals['_ANALYZERSTATEREQUEST']._serialized_end = 965
    _globals['_ANALYZERSTATERESPONSE']._serialized_start = 967
    _globals['_ANALYZERSTATERESPONSE']._serialized_end = 1069
    _globals['_ANALYZERINFOREQUEST']._serialized_start = 1071
    _globals['_ANALYZERINFOREQUEST']._serialized_end = 1113
    _globals['_ANALYZERINFORESPONSE']._serialized_start = 1115
    _globals['_ANALYZERINFORESPONSE']._serialized_end = 1191
    _globals['_ANALYZERSETTINGSREQUEST']._serialized_start = 1193
    _globals['_ANALYZERSETTINGSREQUEST']._serialized_end = 1239
    _globals['_ARESANALYZERMANAGEMENTSERVICE']._serialized_start = 1242
    _globals['_ARESANALYZERMANAGEMENTSERVICE']._serialized_end = 2018


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_planning.proto')
_sym_db = _symbol_database.Default()
from . import planner_adapter_info_pb2 as planner__adapter__info__pb2
from .planning import manual_planner_pb2 as planning_dot_manual__planner__pb2
from .planning import ares_planner_pb2 as planning_dot_ares__planner__pb2
from .planning import planner_status_pb2 as planning_dot_planner__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13ares_planning.proto\x12\x17ares.messaging.planning\x1a\x1aplanner_adapter_info.proto\x1a\x1dplanning/manual_planner.proto\x1a\x1bplanning/ares_planner.proto\x1a\x1dplanning/planner_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto"N\n\x16GetAllPlannersResponse\x124\n\x08planners\x18\x01 \x03(\x0b2".ares.datamodel.PlannerAdapterInfo"+\n\x13CapabilitiesRequest\x12\x14\n\x0cadapter_name\x18\x01 \x01(\t",\n\x14PlannerStatusRequest\x12\x14\n\x0cadapter_name\x18\x01 \x01(\t"0\n\x18PlannerActivationRequest\x12\x14\n\x0cadapter_name\x18\x01 \x01(\t"D\n\x16PlannerSettingsRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x14\n\x0cplanner_name\x18\x02 \x01(\t"T\n\x17PlannerSettingsResponse\x129\n\x08settings\x18\x01 \x03(\x0b2\'.ares.datamodel.planning.PlannerSetting"Z\n\x14CapabilitiesResponse\x12B\n\x12planner_capability\x18\x01 \x03(\x0b2&.ares.messaging.planning.PlannerOption"M\n\x0eGenericPlanner\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x07address\x18\x02 \x01(\x0b2\x1c.google.protobuf.StringValue"C\n\rPlannerOption\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t2\x99\x08\n\x0cAresPlanning\x12Y\n\x0eGetAllPlanners\x12\x16.google.protobuf.Empty\x1a/.ares.messaging.planning.GetAllPlannersResponse\x12u\n\x16GetPlannerCapabilities\x12,.ares.messaging.planning.CapabilitiesRequest\x1a-.ares.messaging.planning.CapabilitiesResponse\x12w\n\x12GetPlannerSettings\x12/.ares.messaging.planning.PlannerSettingsRequest\x1a0.ares.messaging.planning.PlannerSettingsResponse\x12i\n\x10GetPlannerStatus\x12-.ares.messaging.planning.PlannerStatusRequest\x1a&.ares.datamodel.planning.PlannerStatus\x12\\\n\x0fActivatePlanner\x121.ares.messaging.planning.PlannerActivationRequest\x1a\x16.google.protobuf.Empty\x12W\n\x11SeedManualPlanner\x12*.ares.datamodel.planning.ManualPlannerSeed\x1a\x16.google.protobuf.Empty\x12c\n\x14GetManualPlannerSeed\x12\x16.google.protobuf.Empty\x1a3.ares.datamodel.planning.ManualPlannerSetCollection\x12D\n\x12ResetManualPlanner\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12M\n\nAddPlanner\x12\'.ares.messaging.planning.GenericPlanner\x1a\x16.google.protobuf.Empty\x12P\n\rRemovePlanner\x12\'.ares.messaging.planning.GenericPlanner\x1a\x16.google.protobuf.Empty\x12P\n\rUpdatePlanner\x12\'.ares.messaging.planning.GenericPlanner\x1a\x16.google.protobuf.Emptyb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_planning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETALLPLANNERSRESPONSE']._serialized_start = 228
    _globals['_GETALLPLANNERSRESPONSE']._serialized_end = 306
    _globals['_CAPABILITIESREQUEST']._serialized_start = 308
    _globals['_CAPABILITIESREQUEST']._serialized_end = 351
    _globals['_PLANNERSTATUSREQUEST']._serialized_start = 353
    _globals['_PLANNERSTATUSREQUEST']._serialized_end = 397
    _globals['_PLANNERACTIVATIONREQUEST']._serialized_start = 399
    _globals['_PLANNERACTIVATIONREQUEST']._serialized_end = 447
    _globals['_PLANNERSETTINGSREQUEST']._serialized_start = 449
    _globals['_PLANNERSETTINGSREQUEST']._serialized_end = 517
    _globals['_PLANNERSETTINGSRESPONSE']._serialized_start = 519
    _globals['_PLANNERSETTINGSRESPONSE']._serialized_end = 603
    _globals['_CAPABILITIESRESPONSE']._serialized_start = 605
    _globals['_CAPABILITIESRESPONSE']._serialized_end = 695
    _globals['_GENERICPLANNER']._serialized_start = 697
    _globals['_GENERICPLANNER']._serialized_end = 774
    _globals['_PLANNEROPTION']._serialized_start = 776
    _globals['_PLANNEROPTION']._serialized_end = 843
    _globals['_ARESPLANNING']._serialized_start = 846
    _globals['_ARESPLANNING']._serialized_end = 1895


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'analyzing/remote/ares_remote_analyzer_service.proto')
_sym_db = _symbol_database.Default()
from ...analyzing import analysis_pb2 as analyzing_dot_analysis__pb2
from ... import ares_struct_pb2 as ares__struct__pb2
from ...analyzing import analyzer_state_pb2 as analyzing_dot_analyzer__state__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ...analyzing import analyzer_capabilities_pb2 as analyzing_dot_analyzer__capabilities__pb2
from ... import ares_data_schema_pb2 as ares__data__schema__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3analyzing/remote/ares_remote_analyzer_service.proto\x12\x1fares.datamodel.analyzing.remote\x1a\x18analyzing/analysis.proto\x1a\x11ares_struct.proto\x1a\x1eanalyzing/analyzer_state.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%analyzing/analyzer_capabilities.proto\x1a\x16ares_data_schema.proto"\\\n\x1aParameterValidationRequest\x12>\n\x0cinput_schema\x18\x01 \x01(\x0b2(.ares.datamodel.AresDataSchemaSimplified">\n\x19ParameterValidationResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08messages\x18\x02 \x03(\t"k\n\x0fAnalysisRequest\x12*\n\x06inputs\x18\x01 \x01(\x0b2\x1a.ares.datamodel.AresStruct\x12,\n\x08settings\x18\x02 \x01(\x0b2\x1a.ares.datamodel.AresStruct"V\n\x1aAnalysisParametersResponse\x128\n\x10parameter_schema\x18\x01 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema"k\n\x18ConnectionStatusResponse\x12A\n\x06status\x18\x01 \x01(\x0e21.ares.datamodel.analyzing.remote.ConnectionStatus\x12\x0c\n\x04info\x18\x02 \x01(\t"f\n\x15AnalyzerStateResponse\x126\n\x05state\x18\x01 \x01(\x0e2\'.ares.datamodel.analyzing.AnalyzerState\x12\x15\n\rstate_message\x18\x02 \x01(\t"`\n\x0cInfoResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x121\n\x0bdescription\x18\x03 \x01(\x0b2\x1c.google.protobuf.StringValue*R\n\x10ConnectionStatus\x12\x1d\n\x19UNKNOWN_CONNECTION_STATUS\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\x10\n\x0cDISCONNECTED\x10\x022\xf1\x05\n\x19AresRemoteAnalyzerService\x12\x89\x01\n\x0eValidateInputs\x12;.ares.datamodel.analyzing.remote.ParameterValidationRequest\x1a:.ares.datamodel.analyzing.remote.ParameterValidationResult\x12_\n\x07Analyze\x120.ares.datamodel.analyzing.remote.AnalysisRequest\x1a".ares.datamodel.analyzing.Analysis\x12l\n\x15GetAnalysisParameters\x12\x16.google.protobuf.Empty\x1a;.ares.datamodel.analyzing.remote.AnalysisParametersResponse\x12h\n\x13GetConnectionStatus\x12\x16.google.protobuf.Empty\x1a9.ares.datamodel.analyzing.remote.ConnectionStatusResponse\x12Z\n\x08GetState\x12\x16.google.protobuf.Empty\x1a6.ares.datamodel.analyzing.remote.AnalyzerStateResponse\x12P\n\x07GetInfo\x12\x16.google.protobuf.Empty\x1a-.ares.datamodel.analyzing.remote.InfoResponse\x12a\n\x17GetAnalyzerCapabilities\x12\x16.google.protobuf.Empty\x1a..ares.datamodel.analyzing.AnalyzerCapabilitiesb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analyzing.remote.ares_remote_analyzer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONNECTIONSTATUS']._serialized_start = 955
    _globals['_CONNECTIONSTATUS']._serialized_end = 1037
    _globals['_PARAMETERVALIDATIONREQUEST']._serialized_start = 289
    _globals['_PARAMETERVALIDATIONREQUEST']._serialized_end = 381
    _globals['_PARAMETERVALIDATIONRESULT']._serialized_start = 383
    _globals['_PARAMETERVALIDATIONRESULT']._serialized_end = 445
    _globals['_ANALYSISREQUEST']._serialized_start = 447
    _globals['_ANALYSISREQUEST']._serialized_end = 554
    _globals['_ANALYSISPARAMETERSRESPONSE']._serialized_start = 556
    _globals['_ANALYSISPARAMETERSRESPONSE']._serialized_end = 642
    _globals['_CONNECTIONSTATUSRESPONSE']._serialized_start = 644
    _globals['_CONNECTIONSTATUSRESPONSE']._serialized_end = 751
    _globals['_ANALYZERSTATERESPONSE']._serialized_start = 753
    _globals['_ANALYZERSTATERESPONSE']._serialized_end = 855
    _globals['_INFORESPONSE']._serialized_start = 857
    _globals['_INFORESPONSE']._serialized_end = 953
    _globals['_ARESREMOTEANALYZERSERVICE']._serialized_start = 1040
    _globals['_ARESREMOTEANALYZERSERVICE']._serialized_end = 1793